Crate ts_dataplane

Crate ts_dataplane 

ts_dataplane

The packet processing data plane.

The core of the data plane is synchronous and non-blocking, so that it can be wrapped in the user’s choice of sync/async runtimes.

Modules

async_tokio
The packet processing dataplane, as a tokio task.

Structs

DataPlane
Transforms packets to make tailscale happen.
EventResult
The result of processing an event.
InboundResult
The result of processing inbound packets.
OutboundResult
The result of processing outbound packets.

Enums

Subsystem
A data plane subsystem that can be the subject of timer events.