pub struct OutboundResult {
pub to_peers: HashMap<(UnderlayTransportId, PeerId), Vec<PacketMut>>,
pub loopback: HashMap<OverlayTransportId, Vec<PacketMut>>,
}Expand description
The result of processing outbound packets.
Fields
to_peers: HashMap<(UnderlayTransportId, PeerId), Vec<PacketMut>>Packets to be sent into underlay transports for transmission.
loopback: HashMap<OverlayTransportId, Vec<PacketMut>>Packets to be looped back and delivered to overlay transports.