ts_dataplane
The packet processing data plane.
The core of the data plane is synchronous and non-blocking, so that it can be wrapped in the user’s choice of sync/async runtimes.
Modules
- async_
tokio - The packet processing dataplane, as a tokio task.
Structs
- Data
Plane - Transforms packets to make tailscale happen.
- Event
Result - The result of processing an event.
- Inbound
Result - The result of processing inbound packets.
- Outbound
Result - The result of processing outbound packets.
Enums
- Subsystem
- A data plane subsystem that can be the subject of timer events.